@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2018 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
@@ -8,17 +8,25 @@ from openpyxl.descriptors import (
     Sequence,
 )
 
+from .cell_range import CellRange
 
-class MergeCell(Serialisable):
+
+class MergeCell(CellRange):
 
     tagname = "mergeCell"
+    ref = CellRange.coord
+
+    __attrs__ = ("ref",)
 
-    ref = String()
 
     def __init__(self,
                  ref=None,
                 ):
-        self.ref = ref
+        super(MergeCell, self).__init__(ref)
+
+
+    def __copy__(self):
+        return self.__class__(self.ref)
 
 
 class MergeCells(Serialisable):
